######################
# Hardcode PLF build
%bcond_without plf
######################

%if %{with plf}
# make EVR of plf build higher than regular to allow update, needed with rpm5 mkrel
%define extrarelsuffix plf
%endif

%define gstapi 1.0
%define oname Clementine

Summary:	A cross-platform music player based on Amarok 1.4
Name:		clementine
Version:	1.3.1
Release:	9%{?extrarelsuffix}
License:	GPLv3+
Group:		Sound
Url:		http://www.clementine-player.org/
Source0:	https://github.com/clementine-player/Clementine/archive/%{oname}-%{version}.tar.gz
Source1:	Clementine.conf
Patch0:		clementine-1.3-libmygpo-qt.patch
# Search albums at metal-archives.com (Encyclopaedia Metallum) from:
# - Now Playing widget (album art context menu) - current album
# - Playlist (selected songs context menu) - unique selected albums
Patch1:		clementine-1.3-metalarchives.patch
Patch4:		clementine-1.3-initial-preference.patch
# Localization issues
Patch5:		clementine-1.3-l10n-ru-desktop.patch
Patch6:		clementine-1.3-l10n-ru-search.patch
Patch7:		clementine-1.3-play-folder.patch
# RockRadio.com has Premium access for long time already
# It's especially imported to fix after free access to DI.fm services was disabled
# https://github.com/clementine-player/Clementine/commit/3ab20defce71a009bf180255642c18fa671650f9
Patch8:		clementine-1.3.1-rockradio-premium.patch
Patch9:		clementine-1.3.1-sqlite-3.12.patch

# Upstream patches
Patch10:	clementine-1.3.1-fix-playlist-behaviour.patch
Patch11:	clementine-1.3.1-remove-echonest-1.patch
Patch12:	clementine-1.3.1-remove-echonest-2.patch
Patch13:	clementine-1.3.1-remove-echonest-3.patch
Patch14:	clementine-1.3.1-remove-echonest-4.patch
Patch15:	clementine-1.3.1-remove-echonest-5.patch
Patch16:	clementine-1.3.1-remove-echonest-6.patch
Patch17:	clementine-1.3.1-remove-echonest-7.patch

# Fix channels loading for DI.fm services after API domain changes
Patch20:	clementine-1.3.1-radio-channels-api.patch

BuildRequires:	cmake
BuildRequires:	qt4-linguist
BuildRequires:	boost-devel
BuildRequires:	liblastfm-devel
BuildRequires:	qt4-devel >= 4.5.0
BuildRequires:	pkgconfig(cryptopp)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gstreamer-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-app-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-audio-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-base-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-tag-%{gstapi})
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libcdio)
BuildRequires:	pkgconfig(libchromaprint)
BuildRequires:	pkgconfig(libgpod-1.0)
BuildRequires:	pkgconfig(libmtp)
BuildRequires:	pkgconfig(libmygpo-qt)
# For Google Drive and Amazon Cloud integration
BuildRequires:	pkgconfig(libsparsehash)
%if %{with plf}
BuildRequires:	protobuf-static-devel
BuildRequires:	pkgconfig(libspotify)
%endif
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(QJson)
BuildRequires:	pkgconfig(taglib) >= 1.6
Requires:	libprojectm-data
Requires:	qt4-database-plugin-sqlite
Requires:	gstreamer%{gstapi}-flac
Requires:	gstreamer%{gstapi}-plugins-ugly
Suggests:	gstreamer%{gstapi}-decoders-audio
Suggests:	gstreamer%{gstapi}-faac
Suggests:	gstreamer%{gstapi}-faad
Suggests:	gstreamer%{gstapi}-lame
# Needed to be able to mount ipod/iphone/ipad (not tested locally) but it's also pulling gvfs
# which is need at least to mount mtp devices (tested locally)
Suggests:	gvfs-iphone

%description
Clementine is a modern music player and library organiser. Clementine is
a port of Amarok 1.4, with some features rewritten to take advantage of
Qt4.
Features:
    * Search and play your local music library
    * Listen to internet radio from Last.fm, SomaFM and Magnatune
    * Tabbed playlists, import and export M3U, XSPF, PLS and ASX
    * Visualisations from projectM
    * Transcode music into MP3, Ogg Vorbis, Ogg Speex, FLAC or AAC
    * Edit tags on MP3 and OGG files, organize your music
    * Download missing album cover art from Last.fm
    * Remote control using a Wii Remote, MPRIS or the command-line
    * Copy music to your iPod, iPhone, MTP or mass-storage USB player
    * Queue manage

%files
%config %{_sysconfdir}/Clementine/Clementine.conf
%{_bindir}/clementine
%{_bindir}/clementine-tagreader
%{_datadir}/kde4/services/clementine-*.protocol
%{_datadir}/appdata/clementine.appdata.xml
%{_datadir}/applications/clementine.desktop
%{_iconsdir}/hicolor/*/apps/clementine.*
%if %{with plf}
%{_bindir}/clementine-spotifyblob
%endif

#----------------------------------------------------------------------------

%prep
%setup -qn %{oname}-%{version}
%patch0 -p1 -b .mygpo~
%patch1 -p1 -b .ma~
%patch4 -p1 -b .initial~
%patch5 -p1 -b .l10n~
%patch6 -p1 -b .l10n~
%patch7 -p1 -b .desktop~
%patch8 -p1 -b .rockradio~
%patch9 -p1 -b .sqlite312~

%patch10 -p1 -b .playlist~
%patch11 -p1 -b .echonest1~
%patch12 -p1 -b .echonest2~
%patch13 -p1 -b .echonest3~
%patch14 -p1 -b .echonest4~
%patch15 -p1 -b .echonest5~
%patch16 -p1 -b .echonest6~
%patch17 -p1 -b .echonest7~

%patch20 -p1 -b .api~

%build
%cmake_qt4 \
	-DENABLE_AMAZON_CLOUD_DRIVE:BOOL=ON \
	-DENABLE_VK=OFF \
	-DBUNDLE_PROJECTM_PRESETS=OFF \
	-DBUILD_WERROR=OFF
%make VERBOSE=1

%install
%makeinstall_std -C build

install -m 644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/Clementine/Clementine.conf

%if %{with plf}
# Ugly hack, not sure why that file appears
rm -rf %{buildroot}/builddir
rm -rf %{buildroot}/home
%endif


%changelog

* Sat Mar 10 2018 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-9plf
- (1c7d0f0) Fix channels loading for DI.fm services after API domain changes

* Tue Jan 09 2018 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-8plf
- (af296c7) Bump release

* Mon Aug 14 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-7plf
- (c6b32be) Disable OSD by default (doesn't work properly in new DEs)
- (c6b32be) Really disable vk.com support

* Wed Aug 09 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-6plf
- (994f998) Add upstream patches to fix artist info page (drop dead echonest support etc)
- (994f998) Don't build vk.com support as external players are no longer supported by vk.com

* Thu Sep 29 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-5plf
- (39f1e1a) Bump release

* Thu Sep 15 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-4plf
- (e0af23c) Bump release

* Tue Aug 30 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-3plf
- (2f25187) Bump release

* Fri May 27 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-2plf
- (28a8020) Add patch to support sqlite 3.12+

* Tue May 03 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3.1-1plf
- (6b3512d) New version 1.3.1
- (6b3512d) Fix RockRadio.com access (still requires premium Di.fm account)

* Sat Apr 16 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.3-1plf
- (565038b) PLF build requires protobuf-static-devel
- (Andrey Bondrov: 3f89a7f) New version 1.3
- (Andrey Bondrov: 3f89a7f) Swicth to GStreamer 1.0 API
- (Andrey Bondrov: 3f89a7f) Update BuildRequires and files
- (Andrey Bondrov: 3f89a7f) Use internal vreen library by default (because of very unstable API)

* Wed Jan 06 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-9plf
- (9ce3c1c) Fix play-folder patch after initial-preference patch was updated
- (Andrey Bondrov: 181a797) InitialPreference should be lower than 10

* Wed Nov 18 2015 Denis Silakov <dsilakov@gmail.com> 1.2.3-8plf
- (9815414) Add inode/directory to supported mime types

* Fri Oct 09 2015 Denis Silakov <denis.silakov@rosalab.ru> 1.2.3-7plf
- (95d2327) Suggest gstreamer-lame

* Mon Sep 28 2015 Denis Silakov <denis.silakov@rosalab.ru> 1.2.3-6plf
- (3ce1b5d) Rebuild with new libimobiledevice and libplist

* Tue May 26 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-5plf
- (ed3e01e) Add initial-preference patch to give Clementine high priority for supported file formats

* Tue May 26 2015 Denis Silakov <denis.silakov@rosalab.ru> 1.2.3-4plf
- (3bb6aa1) Suggest gstreamer faac and faad

* Sat Nov 08 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-3plf
- (470ae06) Bump release

* Tue Jul 01 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-2plf
- (ff67727) Add patch to fix build with cmake 3.0

* Mon May 26 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-1plf
- (1364ca9) Make build verbose
- (Andrey Bondrov: 9a3faf1) New version 1.2.3

* Wed May 07 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.2-2plf
- (c457aa7) Bump release

* Mon Mar 03 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.2-1plf
- (f68c09a) LOG New version 1.2.2

* Mon Oct 28 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-8plf
- (6b33cab) LOG Improve Vk.com support (now supports albums/playlists), fix minor localization issues

* Thu Oct 24 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-6plf
- (d40dfb3) LOG Improve VKontakte support

* Tue Oct 22 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-5plf
- (427a229) LOG Update russian translation for .desktop file
- (Andrey Bondrov: 290f0e8) LOG Add russian strings to desktop file, don't read tags for vk.com music files (it fixes encoding issues because we already have tags properly set)

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-4plf
- (0e18bec) LOG Add patch for VKontakte support

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-3plf
- (fd14cf4) Adjust removal of junk from buildroot


